@@ -241,61 +241,61 @@ head(PES.sqrt)
 #  head(PES.absolute)
 #  
 
-## ---- fig.width= 7, fig.height= 5-------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
+## ---- fig.width= 7, fig.height= 5, eval=FALSE-------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
+#  
+#  data(PhyloExpressionSetExample)
+#  
+#  # plotting the TAI using log2 transformed expression levels
+#  # and performing the Flat Line Test to obtain the p-value
+#  PlotPattern( ExpressionSet = tf(PhyloExpressionSetExample, log2),
+#               type          = "l",
+#               lwd           = 5,
+#               TestStatistic = "FlatLineTest",
+#               xlab          = "Ontogeny",
+#               ylab          = "TAI" )
+#  
+#  
 
-data(PhyloExpressionSetExample)
-
-# plotting the TAI using log2 transformed expression levels
-# and performing the Flat Line Test to obtain the p-value
-PlotPattern( ExpressionSet = tf(PhyloExpressionSetExample, log2),
-             type          = "l", 
-             lwd           = 5,  
-             TestStatistic = "FlatLineTest",
-             xlab          = "Ontogeny", 
-             ylab          = "TAI" )
-
-
-
-## ---- fig.width= 7, fig.height= 5-------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
-
-data(PhyloExpressionSetExample)
-
-# plotting the TAI using sqrt transformed expression levels
-# and performing the Flat Line Test to obtain the p-value
-PlotPattern( ExpressionSet = tf(PhyloExpressionSetExample, sqrt),
-             TestStatistic = "FlatLineTest",
-             type          = "l", 
-             lwd           = 5,
-             xlab          = "Ontogeny", 
-             ylab          = "TAI" )
-
-
-
-## ---- fig.width= 7, fig.height= 5-------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
-data(DivergenceExpressionSetExample)
-
-# plotting the TDI using log2 transformed expression levels
-# and performing the Flat Line Test to obtain the p-value
-PlotPattern( ExpressionSet = tf(DivergenceExpressionSetExample, log2),
-             TestStatistic = "FlatLineTest",
-             type          = "l", 
-             lwd           = 5,
-             xlab          = "Ontogeny", 
-             ylab          = "TDI" )
-
-
-
-## ---- fig.width= 7, fig.height= 5-------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
-data(DivergenceExpressionSetExample)
-
-# plotting the TDI using sqrt transformed expression levels
-# and performing the Flat Line Test to obtain the p-value
-PlotPattern( ExpressionSet = tf(DivergenceExpressionSetExample, sqrt),
-             TestStatistic = "FlatLineTest",
-             type          = "l", 
-             lwd           = 5,
-             xlab          = "Ontogeny", 
-             ylab          = "TDI" )
+## ---- fig.width= 7, fig.height= 5, eval=FALSE-------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
+#  
+#  data(PhyloExpressionSetExample)
+#  
+#  # plotting the TAI using sqrt transformed expression levels
+#  # and performing the Flat Line Test to obtain the p-value
+#  PlotPattern( ExpressionSet = tf(PhyloExpressionSetExample, sqrt),
+#               TestStatistic = "FlatLineTest",
+#               type          = "l",
+#               lwd           = 5,
+#               xlab          = "Ontogeny",
+#               ylab          = "TAI" )
+#  
+#  
 
+## ---- fig.width= 7, fig.height= 5, eval=FALSE-------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
+#  data(DivergenceExpressionSetExample)
+#  
+#  # plotting the TDI using log2 transformed expression levels
+#  # and performing the Flat Line Test to obtain the p-value
+#  PlotPattern( ExpressionSet = tf(DivergenceExpressionSetExample, log2),
+#               TestStatistic = "FlatLineTest",
+#               type          = "l",
+#               lwd           = 5,
+#               xlab          = "Ontogeny",
+#               ylab          = "TDI" )
+#  
+#  
 
+## ---- fig.width= 7, fig.height= 5, eval=FALSE-------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
+#  data(DivergenceExpressionSetExample)
+#  
+#  # plotting the TDI using sqrt transformed expression levels
+#  # and performing the Flat Line Test to obtain the p-value
+#  PlotPattern( ExpressionSet = tf(DivergenceExpressionSetExample, sqrt),
+#               TestStatistic = "FlatLineTest",
+#               type          = "l",
+#               lwd           = 5,
+#               xlab          = "Ontogeny",
+#               ylab          = "TDI" )
+#  
+#  
 
